@@ -7,16 +7,20 @@ class Config(BaseModel):
 
     Attributes:
         __config_name__: 配置名称。
+        adapter_type: 适配器类型，需要和协议端配置相同。
         host: 本机域名。
         port: 监听的端口。
-        url: WebSocket 路径，需和客户端配置相同。
+        url: WebSocket 路径，需和协议端配置相同。
+        reconnect_interval: 重连等待时间。
         api_timeout: 进行 API 调用时等待返回响应的超时时间。
+        access_token: 鉴权。
     """
-    __config_name__ = 'cqhttp'
-    adapter_type: str = 'reverse-ws'
-    host: str = '127.0.0.1'
+
+    __config_name__ = "cqhttp"
+    adapter_type: str = "reverse-ws"
+    host: str = "127.0.0.1"
     port: int = 8080
-    url: str = '/cqhttp/ws'
+    url: str = "/cqhttp/ws"
     reconnect_interval: int = 3
     api_timeout: int = 1000
-    access_token: str = ''
+    access_token: str = ""
